@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extension.c,v 1.8 2006/09/13 19:01:07 chpe Exp $
+ *  $Id$
  */
 
 #include "config.h"
@@ -26,6 +26,7 @@
 #include "error-viewer.h"
 #include "link-checker.h"
 #include "sgml-validator.h"
+#include "mozilla-helpers.h"
 #include "ephy-debug.h"
 
 #include <gmodule.h>
@@ -38,6 +39,9 @@ register_module (GTypeModule *module)
 {
 	LOG ("Registering EphyErrorViewerExtension");
 
+        if (!mozilla_glue_startup ())
+              return 0;
+
 #ifdef ENABLE_NLS
 	/* Initialize the i18n stuff */
 	bindtextdomain (GETTEXT_PACKAGE, EPHY_EXTENSIONS_LOCALEDIR);
